@@ -1,9 +1,16 @@
-/* ulpget.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -12,7 +19,7 @@ static integer c__1 = 1;
 /* ----------------------------------------------------------------------- */
 /*     ULPGET / ULPSET / ULPSTX */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int ulpget_0_(int n__, char *cp, integer *ipara, ftnlen 
 	cp_len)
@@ -20,7 +27,7 @@ static integer c__1 = 1;
     static char cl[40];
     static integer ip;
     static char cx[8];
-    static integer it;
+    static integer it, idx;
     extern /* Subroutine */ int rliget_(char *, integer *, integer *, ftnlen),
 	     uliqid_(char *, integer *, ftnlen), rllget_(char *, integer *, 
 	    integer *, ftnlen), ullqid_(char *, integer *, ftnlen), ulpqid_(
@@ -33,7 +40,6 @@ static integer c__1 = 1;
 	    *, integer *), ulisvl_(integer *, integer *), ullsvl_(integer *, 
 	    integer *), ulpqvl_(integer *, integer *), ulpsvl_(integer *, 
 	    integer *), ulrsvl_(integer *, integer *);
-    static integer idx;
 
     switch(n__) {
 	case 1: goto L_ulpset;
